package ipl;
import java.awt.*;
import java.awt.image.*;
import gui.*;
import lyon.dclap.*;

class Histogram extends PictFrame {
	
	public int red[] = new int[256];
	public int green[] = new int[256];
	public int blue[] = new int[256];
	public int intensity[] = new int[256];
	public int k1 = 80;	//	height of every histogram
	public int k2;		//	height of a string + 8
	public int tp = 0;	//	number of total pixels

	public Histogram(PixelPlane p) {
		super("RGB Levels Histogram Information");
		setBackground(Color.white);
		for (int i=0; i<256; i++) {
			red[i] = 0;
			green[i] = 0;
			blue[i] = 0;
		}
		tp = p.getLength();
		for (int i=0; i<tp; i++) {
			red[p.getRed(i)]+=1;
			green[p.getGreen(i)]+=1;
			blue[p.getBlue(i)]+=1;
		}

		for (int i=0; i<intensity.length; i++) {
			intensity[i] = (red[i]+green[i]+blue[i])/3;
		}
		normalize(red);
		normalize(green);
		normalize(blue);
		normalize(intensity);
		reshape(10,10,300,470);
		resize(300,470);
		setResizable(false);
		repaint();
		show();
	}

	public void normalize(int[] array) {
	//	normalizes the array so that all its values are between 0 and 1
	//	then it multiplies every value by k1 constant
		int highest=0;
		for (int i=0; i<array.length; i++) {
			if (array[i]>highest) {
				highest = array[i];
			}
		}
		for (int i=0; i<array.length; i++) {
			array[i] = (int)(array[i]/((double)highest)*k1);
		}
	}


	public void paint(Graphics g) {
		k2 = getFontMetrics(g.getFont()).getHeight()+8;
		g.setColor(Color.red);
		drawVerticalString(g,"Red",20,k1/2+10);
		g.setColor(Color.green);
		drawVerticalString(g,"Green",20,k1/2+10+k1+k2);
		g.setColor(Color.blue);
		drawVerticalString(g,"Blue",20,k1/2+10+2*(k1+k2));
		g.setColor(Color.black);
		drawVerticalString(g,"Intensity",20,k1/2+10+3*(k1+k2));
		g.setColor(Color.red);
		drawHistogram(g,red,30,10);
		g.setColor(Color.green);
		drawHistogram(g,green,30,10+k1+k2);
		g.setColor(Color.blue);
		drawHistogram(g,blue,30,10+2*(k1+k2));
		g.setColor(Color.black);
		drawHistogram(g,intensity,30,10+3*(k1+k2));
		g.drawString("Total Pixels: "+tp,15,435);
	}

	public void drawHistogram(Graphics g,int array[],int x,int y) {
	//	draws a histogram based on the array that is passed to it
		g.drawLine(x,y,x,y+k1);
		g.drawLine(x+array.length,y,x+array.length,y+k1);
		g.drawLine(x,y,x+array.length,y);
		g.drawLine(x,y+k1,x+array.length,y+k1);
		//	draws the rectangle
		for (int i = 0; i<array.length; i++) {
			g.drawLine(x+i,y+k1-array[i],x+i,y+k1);
			//	plots the data
			if (i%10==0) {
				g.drawLine(x+i,y+k1,x+i,y+k1+4);
				//	grid lines every ten points
			}
			if (i%50==0) {
				String str = new String(String.valueOf(i));
				int str_height = g.getFontMetrics().getHeight();
				int str_width = g.getFontMetrics().stringWidth(str);
				g.drawString(str,x+i-str_width/2,y+k1+6+str_height);
				//	writes the value every 50 points
			}
		}
	}

	public void drawVerticalString(Graphics g,String str,int x,int y) {
	//	draws a vertical string whose center is located in the passes coordinates
		int str_height = g.getFontMetrics().getHeight();
		y=y-(str_height*str.length())/2;
		for (int i = 0; i<str.length(); i++) {
			int char_width = g.getFontMetrics().stringWidth(str.substring(i,i+1));
			g.drawString(str.substring(i,i+1),x-char_width/2,y);
			y+=str_height;
		}
	}
}